{smcl}
{* 29Jun2008}{...}
{cmd:help wfdataset}
{hline}

{title:Title}

{p2colset 5 12 24 2}{...}
{p2col:{hi:TO DO:Steps to create and save a dataset}}{p_end}
{p2colreset}{...}

{title:List of examples}
{synoptset 15 tabbed}{...}

{p2col:X.}{p_end}
{p2col:X.}{p_end}
{p2col:X.}{p_end}
{p2col:X.}{p_end}
{p2col:X.}{p_end}
{p2col:X.}{p_end}

{title:1. Drop variables and/or observations}
keep if exp
drop if exp

keep in start/end [if exp]
drop in start/end [if exp]

{title:Create new variables}

generate newvar = exp [if] [in]
clonevar newvar = sourcevar [if] [in]
replace newvar = exp [if] [in]

Principles for creating new variables

    There are four simple principles for creating new variables.

1.If a variable is new, give it a new name.
2.Verify that new variables are constructed correctly.
3.Document new variables with notes and labels.
4.Keep the source variables used to create new variables.

{title:Labels and notes for variables}

      label variable varname "label"
         While I generally do not abbreviate commands, I often use the abbreviation label var which is shorter yet still clear. For example,[1.0]<LaTeX>\singlespacing</LaTeX>

    label var artsqrt "Square root of # of articles"



Listing variable labels and other information

       codebook [varlist] [if] [in] , compact
       describe [varlist] [if] [in] , simple fullnames numbers

    . nmlab id tc1fam tc2fam tc3fam vignum
 tabulate

     local tag "pub# truncated at 20 \ wf5-varnotes.do jsl 2008-04-09."
    note pub1trunc: `tag'

{title:Adding value labels

Step 1: Defining labels
    In the first step, I define a set of labels to be associated with values without indicating which variables use these labels. For yes/no questions with yes coded 1 and no coded 0, I could define the label as:[1.0]<LaTeX>\singlespacing</LaTeX>

    label define yesno 1 yes 0 no

 Step 2: Assigning labels
    After labels are defined, label value assigns the defined labels to one or more variables. For example, since wc and hc are yes/no questions, I can use the label definition yesno for both variables:[1.0]<LaTeX>\singlespacing</LaTeX>

    label value wc yesno

1) Keep labels short Value labels should be eight or fewer characters in length.

2) Include the category number
Adding values to value labels<label>wf5-addnumberstovallabel</label>
    numlabel defnot, mask(#) add

    3) Avoid special characters



4) Keeping track of where labels are used
    [1.5]<LaTeX>\onehalfspacing</LaTeX>To keep track of whether a label is used for a single variable or many variables, I use these rules:

If a value label is assigned to only one variable, the label definition should have the same name as the variable.
If a value label is assigned to multiple variables, the name of the label definition should begin with L.
    For example, I would define label define female 0 0_Male 1 1_Female and use it with the variable female. I would define label define Lyesno 1 1_Yes 0 0_No to remind me that if I change the definition of Lyesno I need to verify that the change is appropriate for all of the variables using this definition.

Removing labels
    To remove an assigned value label, use label value without specifying the label. For example, to remove the yesno label assigned to wc:[1.0]<LaTeX>\singlespacing</LaTeX>

    label value wc

    [1.5]<LaTeX>\onehalfspacing</LaTeX>In the latest version of Stata 10 you can use a new syntax where a period indicates that the label is being removed:[1.0sp]<LaTeX>\singlespacing</LaTeX>

    label value wc .

    [1.5]<LaTeX>\onehalfspacing</LaTeX>While I have removed the yesno label from wc, the label definition has not been deleted and can be used by other variables.    }


{title:Recoding}

    . recode edyears 0/8=1 9/11=2 12=3 13/15=4 16/24=5, gen(educcat2)
    (1636 differences between edyears and educcat2)

    [1.5]<LaTeX>\onehalfspacing</LaTeX>I am specifying that source values from 0 through 8 be recoded to 1; values 9 through 11 be recoded to 2; and so on. The gen option indicates that I want to create a variable named educcat2.
    To recode 1 to 0 and change all other values, including missing, to 1 I use * to indicate "all other values":
     !! wf6072.log.tex:
    [1.0]<LaTeX>\singlespacing</LaTeX>

    . recode edyears 1=0 *=1, gen(edtest1)
    (1798 differences between edyears and edtest1)

    [1.5]<LaTeX>\onehalfspacing</LaTeX>If I do not want missing values to be recoded, I exclude those cases with an if condition:
     !! wf6073.log.tex:
    [1.0]<LaTeX>\singlespacing</LaTeX>

    . recode edyears 1=0 *=1 if !missing(edyears), gen(edtest2)
    (1639 differences between edyears and edtest2)

    [1.5]<LaTeX>\onehalfspacing</LaTeX>To leave 1 through 5 unchanged and recode 6 through 24 to 6:
     !! wf6074.log.tex:
    [1.0]<LaTeX>\singlespacing</LaTeX>

    . recode edyears 6/24=6 if !missing(edyears), gen(edtest3)
    (1546 differences between edyears and edtest3)

    [1.5]<LaTeX>\onehalfspacing</LaTeX>To change the values 1, 3, 5, 7, and 9 to -1, leaving other values unchanged:
     !! wf6075.log.tex:
    [1.0]<LaTeX>\singlespacing</LaTeX>

    . recode edyears 1 3 5 7 9=-1, gen(edtest4)
    (182 differences between edyears and edtest4)

    [1.5]<LaTeX>\onehalfspacing</LaTeX>To recode values from 6 to the maximum to 6, leaving other values unchanged:
     !! wf6076.log.tex:
    [1.0]<LaTeX>\singlespacing</LaTeX>

    . recode edyears 6/max=6, gen(edtest5)
    (1546 differences between edyears and edtest5)

    [1.5]<LaTeX>\onehalfspacing</LaTeX>Note that max stands for the maximum non-missing value; min stands for the minimum value.

{title:Rearrange variables within the dataset.}

aorder [varlist]
order varlist
move variable-to-move target-variable

aorder
order id

{title:Run diagnostics to look for data problems.}

    codebook, problem
    isid varlist
    duplicates report id
    duplicates examples, clean


{title:Internal documentation for a dataset.}

    label data "Workflow data from Russian ISSP 2002 \ 2008-04-02"
    note: wf-isspru02.dta \ workflow ch 6 \ wf6-save.do jsl 2008-04-05


{title:datasignature}

    datasignature set
    use wf-datasig02, clear
    datasignature confirm
    datasignature set, reset


{title:Saving the dataset}

quietly compress
saveold xxx, replace   saveold filename [, replace]

{title:Also see}

    {helpb wf}
INCLUDE help wf_footer
